"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require('fs');
var parser = require("gitignore-parser");
var SlIgnoreWrapper = /** @class */ (function () {
    function SlIgnoreWrapper(slIgnoreFilePath, outputPath, filename, logger) {
        this.slIgnoreFilePath = slIgnoreFilePath;
        this.outputPath = outputPath;
        this.filename = filename;
        this.logger = logger;
        this.parsed = this.getParser();
    }
    SlIgnoreWrapper.prototype.getParser = function () {
        var pattern = this.getIgnorePattern();
        try {
            var compiled = parser.compile(pattern); //may throw if the file is invalid/corrupted
            return compiled;
        }
        catch (e) {
            this.logger.error("Error while trying to use .slignore pattern, pattern seems to be corrupted. Using default behavior.");
            pattern = this.getDefaultPattern();
            return parser.compile(pattern); //should not throw again
        }
    };
    SlIgnoreWrapper.prototype.getIgnorePattern = function () {
        if (!this.slIgnoreFilePath) {
            this.logger.info("'%s' file does not exists, Using default behavior.", this.filename);
            return this.getDefaultPattern();
        }
        try {
            var pattern = fs.readFileSync(this.slIgnoreFilePath, 'utf8');
            this.logger.info("Using '%s' file '%s'", this.filename, this.slIgnoreFilePath);
            return this.addExcludedPath(pattern, this.outputPath);
        }
        catch (err) {
            this.logger.info("Failed to read from: '%s'. Using default behavior.", this.slIgnoreFilePath);
            return this.getDefaultPattern();
        }
    };
    SlIgnoreWrapper.prototype.addExcludedPath = function (pattern, excludedFolder) {
        if (!excludedFolder)
            return pattern;
        if (excludedFolder && excludedFolder[excludedFolder.length - 1] != '/') {
            excludedFolder += '/';
        }
        pattern = pattern + "\n" + excludedFolder;
        return pattern;
    };
    SlIgnoreWrapper.prototype.getDefaultPattern = function () {
        // default pattern - all js files under test directory and it's sub directories.
        var pattern = "";
        pattern = this.addExcludedPath(pattern, this.outputPath);
        return pattern;
    };
    SlIgnoreWrapper.prototype.denies = function (input) {
        return this.parsed.denies(input);
    };
    SlIgnoreWrapper.prototype.accepts = function (input) {
        return this.parsed.accepts(input);
    };
    SlIgnoreWrapper.SCAN_IGNORE_FILE_NAME = ".slignore";
    SlIgnoreWrapper.GENERATED_IGNORE_FILE_NAME = ".slignore.generated";
    return SlIgnoreWrapper;
}());
exports.SlIgnoreWrapper = SlIgnoreWrapper;
//# sourceMappingURL=sl-ignore-wrapper.js.map